@@ -334,12 +334,18 @@ class UserService:
 
         self._raise_response_error(response)
 
-    def get_otp(self, credential_type: str, identity: str) -> str:
+    def get_otp(
+        self, credential_type: str, identity: str, region=CountryCode.INDIA
+    ) -> str:
         if credential_type != CredentialType.MOBILE.value:
             raise TypeNotSupported
 
         cred_type = CredentialType(credential_type)
-        params = {"credential_type": cred_type.name, "identity": identity}
+        params = {
+            "credential_type": cred_type.name,
+            "identity": identity,
+            "region": region,
+        }
         request_url = f"{self._authentication_url}/api/v1/sessions/otp"
         response = requests.get(request_url, params=params)
         if response.status_code == HTTPStatus.OK:
